@@ -10,7 +10,7 @@ class Capybara::Driver::Base
   def find_xpath(query)
     raise NotImplementedError
   end
-  
+
   def find_css(query)
     raise NotImplementedError
   end
@@ -19,6 +19,14 @@ class Capybara::Driver::Base
     raise NotImplementedError
   end
 
+  def go_back
+    raise Capybara::NotSupportedByDriverError, 'Capybara::Driver::Base#go_back'
+  end
+
+  def go_forward
+    raise Capybara::NotSupportedByDriverError, 'Capybara::Driver::Base#go_forward'
+  end
+
   def execute_script(script)
     raise Capybara::NotSupportedByDriverError, 'Capybara::Driver::Base#execute_script'
   end
