@@ -35,4 +35,11 @@ Capybara::SpecHelper.spec '#within_window', :requires => [:windows] do
     end
     @session.find("//*[@id='divInMainWindow']").text.should eql 'This is the text for divInMainWindow'
   end
+  it "should reset scope when switching windows" do
+    @session.within(:css, '#divInMainWindow') do
+      @session.within_window("secondPopup") do
+        @session.find("//*[@id='divInPopupTwo']").text.should eql 'This is the text of divInPopupTwo'
+      end
+    end
+  end
 end
